@@ -1,8 +1,9 @@
 from .compile import compile
+from .common import checkData as upload_data
 from .predict import predict
 from .train import train
 from .common import api
 from .Dataset import Dataset
-from .Model import Model
+from .Model import Model, NLPHFModel, nlp_constructor
 from .export import export
 from .DataLoader import DataLoader
