@@ -1,9 +1,9 @@
-import hashlib
+import os
 
 import bson
 import requests
 
-from .common import getToken, read_in_chunks, MID_VERBOSITY, getVerbosity
+from .common import getToken, read_in_chunks, MID_VERBOSITY, getVerbosity, get_progress_bar_uploader, convert_size
 from .Task import Task
 from .saving.saving import determine_model, hash_model
 from .web.urls import RETRIEVE_MODEL_URL, HASH_URL, COMPILE_URL
@@ -11,6 +11,8 @@ from .saving import save_model
 
 
 def compile(model, input_shape, library, model_label, asynchronous=False):
+    if not isinstance(model_label, str):
+        raise ValueError("Name given is not valid. Please supply a string.")
     if model_label != "" and model is None:
         print(model_label)
         params = {"token": getToken(), "input_shape": input_shape, "label": model_label}
@@ -19,7 +21,7 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             return response
         else:
             raise LookupError("Model not found. " + str(response))
-    if bson.ObjectId.is_valid(model):
+    if bson.ObjectId.is_valid(model) or isinstance(model, Task):
         return model
     if library == "":
         library = determine_model(model)
@@ -30,7 +32,12 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
     if response.status_code == 200:
         if getVerbosity() >= MID_VERBOSITY:
             print("Model already on server. Returning result...")
-        return response.json()
+        response = response.json()
+        if isinstance(response, dict):
+            message = response.get("message")
+            print(message)
+            response = response["id"]
+        return response
     elif response.status_code != 204:
         raise ConnectionAbortedError("Checking hash not worked. {0}".format(response.content))
     else:
@@ -39,16 +46,13 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             print("Saving model locally...")
         file_path = save_model(model, library)
         with open(file_path, "rb") as file:
-            size = 0
-            for piece in read_in_chunks(file):
-                size += len(piece)
-            if model_label == "":
-                model_label = file_path
-            params["given_name"] = model_label
+            file.seek(0, os.SEEK_END)
+            size = file.tell()
             if getVerbosity() >= MID_VERBOSITY:
                 print("Model saved locally.")
-            print("Model file size is {} bytes. Uploading model now...".format(size))
+            print("Model file size is {}. Uploading model now...".format(convert_size(size)))
             task = Task(compileApi(file, params))
+            task.cache = {"model": model}
             if not asynchronous:
                 task.wait()
                 print("Model compiled successfully.")
@@ -57,8 +61,8 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
 
 def compileApi(file, params):
     file.seek(0)
-    files = {'file': file}
-    response = requests.post(COMPILE_URL, files=files, params=params)
+    monitor = get_progress_bar_uploader(file)
+    response = requests.post(COMPILE_URL, data=monitor, headers={'Content-Type': monitor.content_type}, params=params)
     if response.status_code != 200:
         raise ValueError(response.text)
     return response.json()
